@@ -91,24 +91,25 @@ def _read_maps(pid):
     return maps
 
 
-def _command_output(command, input=None, stderr=subprocess.STDOUT):
+def _command_output(command, input=None):
     '''Run command and capture its output.
 
     Try to execute given command (argv list) and return its stdout, or return
     a textual error if it failed.
     '''
-    sp = subprocess.Popen(command, stdout=subprocess.PIPE, stderr=stderr)
+    sp = subprocess.Popen(command, stdout=subprocess.PIPE,
+                          stderr=subprocess.STDOUT)
 
-    (out, err) = sp.communicate(input)
+    out = sp.communicate(input)[0]
     if sp.returncode == 0:
         return out
     else:
-        if err:
-            err = err.decode('UTF-8', errors='replace')
+        if out:
+            out = out.decode('UTF-8', errors='replace')
         else:
-            err = ''
+            out = ''
         raise OSError('Error: command %s failed with exit code %i: %s' % (
-            str(command), sp.returncode, err))
+            str(command), sp.returncode, out))
 
 
 def _check_bug_pattern(report, pattern):
@@ -679,7 +680,8 @@ class Report(problem_report.ProblemReport):
         chroot() or root privileges, it just instructs gdb to search for the
         files there.
 
-        Raises a IOError if the core dump is invalid/truncated.
+        Raises a IOError if the core dump is invalid/truncated, or OSError if
+        calling gdb fails.
         '''
         if 'CoreDump' not in self or 'ExecutablePath' not in self:
             return
@@ -703,11 +705,8 @@ class Report(problem_report.ProblemReport):
             value_keys.append(name)
             gdb_cmd += ['--ex', 'p -99', '--ex', cmd]
 
-        # call gdb
-        try:
-            out = _command_output(gdb_cmd).decode('UTF-8', errors='replace')
-        except OSError:
-            return
+        # call gdb (might raise OSError)
+        out = _command_output(gdb_cmd).decode('UTF-8', errors='replace')
 
         # check for truncated stack trace
         if 'is truncated: expected core file size' in out:
@@ -1515,14 +1514,6 @@ class Report(problem_report.ProblemReport):
                     'reports from foreign architectures. Results with "gdb" '
                     'will be very poor.\n')
 
-            # check for foreign architecture
-            arch = self.get('Uname', 'none').split()[-1]
-            if 'arm' in arch:
-                command += ['--ex', 'set architecture arm', '--ex', 'set gnutarget elf32-littlearm']
-            elif 'ppc' in arch:
-                command += ['--ex', 'set architecture powerpc:common', '--ex', 'set gnutarget elf32-powerpc']
-            # note, i386 vs. x86_64 is auto-detected just fine
-
         if sandbox:
             command += ['--ex', 'set debug-file-directory %s/usr/lib/debug' % sandbox,
                         '--ex', 'set solib-absolute-prefix ' + sandbox]
