@@ -667,7 +667,7 @@ Debug::NoLocking "true";
     def install_packages(self, rootdir, configdir, release, packages,
                          verbose=False, cache_dir=None,
                          permanent_rootdir=False, architecture=None,
-                         origins=None):
+                         origins=None, install_dbg=True):
         '''Install packages into a sandbox (for apport-retrace).
 
         In order to work without any special permissions and without touching
@@ -873,7 +873,7 @@ Debug::NoLocking "true";
                         except KeyError:
                             pass
 
-            if candidate.architecture != 'all':
+            if candidate.architecture != 'all' and install_dbg:
                 try:
                     dbg_pkg = pkg + '-dbg'
                     dbg = cache[dbg_pkg]
